import os

import requests
from requests_toolbelt import MultipartEncoder

from estuary.exceptions import EstuaryException
from estuary.tools import validate_api_key


class Client:

    def __init__(self, api_key: str):
        validate_api_key(api_key)

        self.api_key = api_key
        self.api_request_headers = {'Authorization': f'Bearer {self.api_key}'}

    def upload_file(self, path_to_file: str, *, shuttle_instance='https://shuttle-2.estuary.tech') -> int:
        '''Upload a file to a shuttle instance of Estuary. '''
        api_request_data = MultipartEncoder(fields={
            'data': (os.path.basename(path_to_file), open(path_to_file, 'rb'))
        })

        api_request_headers = self.api_request_headers
        api_request_headers['Content-Type'] = api_request_data.content_type

        api_request = requests.post(f'{shuttle_instance}/content/add', api_request_data, headers=api_request_headers)

        if api_request.status_code != 200:
            raise EstuaryException(api_request.json()['error'])

        return api_request.json()['estuaryId']
